.. image:: https://img.shields.io/pypi/dm/changeo
    :target: https://pypi.org/project/changeo
.. image:: https://img.shields.io/static/v1?label=AIRR-C%20sw-tools%20v1&message=compliant&color=008AFF&labelColor=000000&style=plastic
    :target: https://docs.airr-community.org/en/stable/swtools/airr_swtools_standard.html

Change-O - Repertoire clonal assignment toolkit
================================================================================

Change-O is a collection of tools for processing the output of V(D)J alignment
tools, assigning clonal clusters to immunoglobulin (Ig) sequences, and
reconstructing germline sequences.

Dramatic improvements in high-throughput sequencing technologies now enable 
large-scale characterization of Ig repertoires, defined as the collection of
trans-membrane antigen-receptor proteins located on the surface of B cells and
T cells. Change-O is a suite of utilities to facilitate advanced analysis of
Ig and TCR sequences following germline segment assignment. Change-O
handles output from IMGT/HighV-QUEST and IgBLAST, and provides a wide variety of
clustering methods for assigning clonal groups to Ig sequences. Record sorting, 
grouping, and various database manipulation operations are also included.

**IMPORTANT!** 
Active development of Change-O has moved to https://github.com/immcantation/changeo
